@@ -2,7 +2,6 @@ import boto3
 import json
 
 from .settings import settings
-from .json import UUIDEncoder
 
 
 client = boto3.client(
@@ -13,7 +12,7 @@ client = boto3.client(
 )
 
 
-def publish(topic, body=None, path=None) -> None:
+def publish(topic, body=None, path=None, json_encoder=None) -> None:
     message = {
         'body': body,
         'path': path,
@@ -23,7 +22,7 @@ def publish(topic, body=None, path=None) -> None:
     #     segment = xray_recorder.current_segment()
     #     message['trace_id'] = segment.trace_id
 
-    message = json.dumps(message, cls=UUIDEncoder)
+    message = json.dumps(message, cls=json_encoder)
     message = json.dumps({"default": message})
     resp = client.publish(
         TopicArn=f'{settings.AWS_SNS_PATH}{topic}',
